var indexSectionsWithContent =
{
  0: "abcdefghilmnoprstuvw",
  1: "acfgilmprstw",
  2: "abcdfgilmoprstuv",
  3: "abgior",
  4: "bcfmprst",
  5: "abcdefghilmnoprstuw",
  6: "t"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "functions",
  3: "variables",
  4: "enums",
  5: "enumvalues",
  6: "groups"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Functions",
  3: "Variables",
  4: "Enumerations",
  5: "Enumerator",
  6: "Modules"
};

